==> hermes-2.3.4-788283a3.tar.gz: hermes-2.3.4-788283a3/spec/apis/dmo/required_documents_spec.rb <==
require 'rails_helper'
require 'vcr_config'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')
  include Rack::Test::Methods
  
  describe Api::Dmo::RequiredDocumentsController, type: :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper
    
    let!(:responsible) {create(:user, first_name: 'Martin', last_name: 'Durand', email: 'martin.durand@gmail.com', roles: ['Administrator'])}
    let!(:user) {create(:user, first_name: 'Jackie', last_name: 'Mike', email: 'jackie.mike@gmail.com',auth_roles: ['collaborateur offre logement'] )}
    let!(:applicant) {create(:applicant, user: responsible, nationality: "1")}
    let!(:housing_request1) {create(:housing_request, main_applicant_id: applicant.id.to_s)}
    let(:required_document_id) {housing_request1.housing_request_folder.required_document_ids[0]}
    describe 'PUT /required_documents/:id' do
      describe 'update my required_documents' do
        let(:valid_params) do
          {
            id: required_document_id.to_s,
            data: {attributes: {status: "A contrôler"}}
          }
        end
        
        before :each do
          authenticated_header(request, user)
          put 'update', valid_params
        end
        
        it 'returns status code 200' do
          expect(response.status).to eq(200)
        end
        
        it 'updated form' do
          expect(json['data']['id']).to eq(required_document_id.to_s)
          expect(json['data']['attributes']['status'].first['title']).to eq("A contrôler")
        end
      end
    end
    describe 'DELETE /required_documents/:id/files' do
      before :each do
        hrf = housing_request1.reload.housing_request_folder
    
        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
      end
      describe 'update my required_documents' do
        let(:valid_params) do
          {
            id: required_document_id.to_s
          }
        end
    
        before :each do
        
          authenticated_header(request, responsible)
          delete 'delete_files', valid_params
        end
    
        it 'returns status code 200' do
          expect(response.status).to eq(200)
        end
    
        it 'updated form' do
          expect(json['data']['id']).to eq(required_document_id.to_s)
          expect(json['data']['attributes']['status']).to eq("Pièce manquante")
        end
      end
    end

    describe 'GET /required_documents/:id/historical_status' do 
      let!(:status) {create(:status, object_id: required_document_id)}
      let!(:collaborator) {create(:user, roles: ['collaborateur offre logement'])}
      before :each do
        authenticated_header(request, collaborator)
        get 'historical_status', {id: required_document_id}
      end

      it 'returns status code 200' do
        resp = JSON.parse(response.body)
        expect(resp['code']).to eq(200)
      end
    end 
  end
  
  
  require_relative '../../swagger_helper'
  
  describe Api::Dmo::RequiredDocumentsController, type: :request, swagger_doc: 'api/swagger/hermes/swagger_hermes.json' do
    TAGS_API_DMO_REQUIRED_DOCUMENTS = 'API_DMO_REQUIRED_DOCUMENTS'
    include JwtAuthHelper
    extend HermesSwaggerJsonParams
    include SwaggerJsonAttributes
    let!(:responsible) {create(:user, first_name: 'Martin', last_name: 'Durand', email: 'martin.durand@gmail.com', roles: ['Administrator'])}
    let!(:user) {create(:user, first_name: 'Jackie', last_name: 'Mike', email: 'jackie.mike@gmail.com')}
    let!(:applicant) {create(:applicant, user: user, nationality: "1")}
    let!(:housing_request1) {create(:housing_request,user: user, main_applicant_id: applicant.id.to_s)}
    
    path '/api/dmo/required_documents/{required_document_id}/send_files' do
      post 'send files for to complete the required_document' do
        tags TAGS_API_DMO_REQUIRED_DOCUMENTS
        produces 'application/json'
        parameter name: 'Content-Type', in: :header, type: :string, required: false, description: "must be 'multipart/form-data'"
        consumes 'multipart/form-data'
        #consumes 'application/json'
        parameter name: :required_document_id, in: :path, type: :string
        security [Bearer: {}]
        parameter name: :files, in: :formData, type: :file, description: "files to upload"

        VCR.use_cassette("send_file_to_ged_api_test", :match_requests_on => [:method, :uri, :path]) do
          
          response '200', 'files_uploaded' do
            let(:files) do
              [Rack::Test::UploadedFile.new([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'), "mime/type"), Rack::Test::UploadedFile.new([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'), "mime/type")]
            end
            
            let(:'Content-Type') {'multipart/form-data'}
            let(:Authorization) {"Bearer #{token_for(user)}"}
            let(:required_document_id) {housing_request1.housing_request_folder.required_document_ids[0]}
            include_context 'with integration test'
            include_context 'valid jsonapi'
            include_context 'not containings errors'
            
            after do |_example|
              json_data = JSON.parse(response.body)['data']
              
              expect(json_data).to be_a Hash
              expect(json_data['id']).to_not be nil
              expect(json_data['type']).to eq 'required_documents'
              expect(json_data['attributes']['files'][0]).to be_a Hash
              expect(json_data['attributes']['files'][0]['url']).to_not be nil
            end

          end
          response '422', 'unalowed_because_current_capplication' do
            let(:files) do
              [Rack::Test::UploadedFile.new([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'), "mime/type"), Rack::Test::UploadedFile.new([Hermes::Engine.root, %w[lib hermes tools minion.jpg]].flatten.join('/'), "mime/type")]
            end
            let!(:housing_offer1) {create(:housing_offer)}
            let!(:housing_application3) {create(:housing_application, housing_request: housing_request1, housing_offer: housing_offer1)}

            let(:'Content-Type') {'multipart/form-data'}
            let(:Authorization) {"Bearer #{token_for(user)}"}
            let(:required_document_id) {housing_request1.housing_request_folder.required_document_ids[0]}
        
            run_test!
            after do |_example|
           
            end

          end
        end
      end
    end
  end
end

==> hermes-3.0.1.26.tar.gz: hermes-3.0.1.26/spec/apis/dmo/required_documents_spec.rb <==
require 'rails_helper'
require 'vcr_config'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')
  include Rack::Test::Methods

  describe Api::Dmo::RequiredDocumentsController, type: :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper

    let!(:responsible) {create(:user, roles: ['Administrator'])}
    let!(:applicant) {create(:applicant, user: responsible, nationality: "1")}
    let!(:housing_request1) {create(:housing_request, main_applicant_id: applicant.id.to_s)}
    let(:required_document_id) {housing_request1.housing_request_folder.required_document_ids[0]}

    describe 'PUT /required_documents/:id' do
      shared_examples 'can update required documents' do
        let(:valid_params) do
          {
            id: required_document_id.to_s,
            data: {attributes: {status: "A contrôler"}}
          }
        end
        before :each do
          authenticated_header(request, user)
          put 'update', valid_params
        end

        it 'returns status code 200' do
          expect(response.status).to eq(200)
        end
        it 'updated form' do
          expect(json['data']['id']).to eq(required_document_id.to_s)
          expect(json['data']['attributes']['status']).to eq("A contrôler")
          expect(json['data']['attributes']['status_history'].first['title']).to eq("A contrôler")
        end
      end

      context 'as collaborateur' do
        it_behaves_like 'can update required documents' do
          let(:user) { create(:user, auth_roles: ['collaborateur offre logement']) }
        end
      end

      context 'as superadministrateur' do
        it_behaves_like 'can update required documents' do
          let(:user) { create(:user, auth_roles: ['superadministrateur']) }
        end
      end
    end

    describe 'DELETE /required_documents/:id/files' do
      before :each do
        hrf = housing_request1.reload.housing_request_folder

        required_document = housing_request1.reload.housing_request_folder.required_documents[0]
        file = File.open([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'))
        blob = file.read
        required_document.set_blobs([{filename: "minion.jpg", blob: blob}, {filename: "minion.jpg", blob: blob}])
        required_document.save
      end
      describe 'update my required_documents' do
        let(:valid_params) do
          {
            id: required_document_id.to_s
          }
        end

        before :each do
          authenticated_header(request, responsible)
          delete 'delete_files', valid_params
        end

        it 'returns status code 200' do
          expect(response.status).to eq(200)
        end

        it 'updated form' do
          expect(json['data']['id']).to eq(required_document_id.to_s)
          expect(json['data']['attributes']['status']).to eq("Pièce manquante")
        end
      end
    end

    describe 'GET /required_documents/:id/historical_status' do
      let!(:status) {create(:status, object_id: required_document_id)}
      let!(:collaborator) {create(:user, roles: ['collaborateur offre logement'])}
      before :each do
        authenticated_header(request, collaborator)
        get 'historical_status', {id: required_document_id}
      end

      it 'returns status code 200' do
        resp = JSON.parse(response.body)
        expect(resp['code']).to eq(200)
      end
    end
  end


  require_relative '../../swagger_helper'

  describe Api::Dmo::RequiredDocumentsController, type: :request, swagger_doc: 'api/swagger/hermes/swagger_hermes.json' do
    TAGS_API_DMO_REQUIRED_DOCUMENTS = 'API_DMO_REQUIRED_DOCUMENTS'
    include JwtAuthHelper
    extend HermesSwaggerJsonParams
    include SwaggerJsonAttributes
    let!(:responsible) {create(:user, first_name: 'Martin', last_name: 'Durand', email: 'martin.durand@gmail.com', roles: ['Administrator'])}
    let!(:user) {create(:user, first_name: 'Jackie', last_name: 'Mike', email: 'jackie.mike@gmail.com')}
    let!(:applicant) {create(:applicant, user: user, nationality: "1")}
    let!(:housing_request1) {create(:housing_request,user: user, main_applicant_id: applicant.id.to_s)}

    path '/api/dmo/required_documents/{required_document_id}/send_files' do
      post 'send files for to complete the required_document' do
        tags TAGS_API_DMO_REQUIRED_DOCUMENTS
        produces 'application/json'
        parameter name: 'Content-Type', in: :header, type: :string, required: false, description: "must be 'multipart/form-data'"
        consumes 'multipart/form-data'
        #consumes 'application/json'
        parameter name: :required_document_id, in: :path, type: :string
        security [Bearer: {}]
        parameter name: :files, in: :formData, type: :file, description: "files to upload"

        VCR.use_cassette("send_file_to_ged_api_test", :match_requests_on => [:method, :uri, :path]) do

          response '200', 'files_uploaded' do
            let(:files) do
              [Rack::Test::UploadedFile.new([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'), "mime/type"), Rack::Test::UploadedFile.new([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'), "mime/type")]
            end

            let(:'Content-Type') {'multipart/form-data'}
            let(:Authorization) {"Bearer #{token_for(user)}"}
            let(:required_document_id) {housing_request1.housing_request_folder.required_document_ids[0]}
            include_context 'with integration test'
            include_context 'valid jsonapi'
            include_context 'not containings errors'

            after do |_example|
              json_data = JSON.parse(response.body)['data']

              expect(json_data).to be_a Hash
              expect(json_data['id']).to_not be nil
              expect(json_data['type']).to eq 'required_documents'
              expect(json_data['attributes']['files'][0]).to be_a Hash
              expect(json_data['attributes']['files'][0]['url']).to_not be nil
            end

          end
          response '200', 'unalowed_because_current_capplication' do
            let(:files) do
              [Rack::Test::UploadedFile.new([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'), "mime/type"), Rack::Test::UploadedFile.new([Hermes::Engine.root, %w[spec xml_bouchon minion.jpg]].flatten.join('/'), "mime/type")]
            end
            let!(:housing_offer1) {create(:housing_offer)}
            let!(:housing_application3) {create(:housing_application, housing_request: housing_request1, housing_offer: housing_offer1)}

            let(:'Content-Type') {'multipart/form-data'}
            let(:Authorization) {"Bearer #{token_for(user)}"}
            let(:required_document_id) {housing_request1.housing_request_folder.required_document_ids[0]}

            run_test!
            after do |_example|

            end

          end
        end
      end
    end
  end
end
